@@ -26,8 +26,8 @@ def has_data_access(user, data_user_id, data_group_id=None, was_submitted=False)
     # if dataset was not yet submitted, the user must match
     return any((
         (user.site_read),
-        (was_submitted and data_group_id and data_group_id == user.group_id),
-        (not was_submitted and data_user_id and data_user_id == user.id)
+        (was_submitted and data_group_id is not None and data_group_id == user.group_id),
+        (not was_submitted and data_user_id is not None and data_user_id == user.id)
     ))
 
 def view_apikey(user, target_user):
